@@ -5,12 +5,14 @@ __license__ = 'GPL 2.0/LGPL 2.1'
 __all__ = ('HiddenInputPlugin',)
 
 from django.forms.fields import CharField
-from django.forms.widgets import HiddenInput
+from django.forms.widgets import HiddenInput#, TextInput
 from django.utils.translation import ugettext_lazy as _
 
 from fobi.base import FormFieldPlugin, form_element_plugin_registry, get_theme
 from fobi.contrib.plugins.form_elements.fields.hidden import UID
-from fobi.contrib.plugins.form_elements.fields.hidden.forms import HiddenInputForm
+from fobi.contrib.plugins.form_elements.fields.hidden.forms import (
+    HiddenInputForm
+    )
 
 theme = get_theme(request=None, as_instance=True)
 
@@ -22,6 +24,7 @@ class HiddenInputPlugin(FormFieldPlugin):
     name = _("Hidden")
     group = _("Fields")
     form = HiddenInputForm
+    is_hidden = True
 
     def get_form_field_instances(self):
         """
@@ -37,6 +40,7 @@ class HiddenInputPlugin(FormFieldPlugin):
             kwargs['max_length'] = self.data.max_length
 
         return [(self.data.name, CharField, kwargs)]
+        #return [(self.data.name, (CharField, TextInput), kwargs)]
 
 
 form_element_plugin_registry.register(HiddenInputPlugin)
